"""Add projects table and project_id to todos

Revision ID: 005_add_projects
Revises: 004_add_tags
Create Date: 2025-06-18 15:00:00.000000

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "005_add_projects"
down_revision: Union[str, None] = "004_add_tags"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # Create projects table
    op.create_table(
        "projects",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(length=200), nullable=False),
        sa.Column("description", sa.String(length=500), nullable=True),
        sa.Column(
            "status", sa.Enum("ACTIVE", "ARCHIVED", name="projectstatus"), nullable=True
        ),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("now()"),
            nullable=True,
        ),
        sa.Column("updated_at", sa.DateTime(timezone=True), nullable=True),
        sa.PrimaryKeyConstraint("id"),
    )
    op.create_index(op.f("ix_projects_id"), "projects", ["id"], unique=False)

    # Add project_id column to todos table
    op.add_column("todos", sa.Column("project_id", sa.Integer(), nullable=True))
    op.create_foreign_key(
        "fk_todos_project_id", "todos", "projects", ["project_id"], ["id"]
    )


def downgrade() -> None:
    # Remove foreign key and project_id column from todos
    op.drop_constraint("fk_todos_project_id", "todos", type_="foreignkey")
    op.drop_column("todos", "project_id")

    # Drop projects table
    op.drop_index(op.f("ix_projects_id"), table_name="projects")
    op.drop_table("projects")
